/******************************************************************************
 * $Workfile: BeanService.java $
 * $Revision: 3 $
 * $Author: Edaugherty $
 * $Date: 5/09/02 3:04p $
 *
 ******************************************************************************
 * Copyright (c) 2001-2002, Eric Daugherty
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, 
 * with or without modification, are permitted provided 
 * that the following conditions are met:
 * 
 *   Redistributions of source code must retain the above
 *   copyright notice, this list of conditions and the 
 *   following disclaimer. 
 * 
 *   Redistributions in binary form must reproduce the 
 *   above copyright notice, this list of conditions and 
 *   the following disclaimer in the documentation and/or 
 *   other materials provided with the distribution. 
 * 
 *   Neither the name of Eric Daugherty nor the names of its 
 *   contributors may be used to endorse or promote products 
 *   derived from this software without specific prior written 
 *   permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND 
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

package com.ericdaugherty.lib.bean;

//Java Imports
import java.lang.reflect.*;

//Apache Imports
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

//Local Imports
import com.ericdaugherty.lib.error.SystemException;

/**
 * Provides common methods helpful when dealing with JavaBean interfaces.
 * <p>
 * Please refer to the <a href="package-summary.html#package_description">
 * package level documentation</a> for further information.
 * 
 * @author <a href="mailto:java@ericdaugherty.com">Eric Daugherty</a> (<a href="http://www.ericdaugherty.com/java/daughertylib">http://www.ericdaugherty.com/java/daughertylib</a>)
 */
public class BeanService
{
	
	/**
	 * This method copies one JavaBean Implementation to another.  Both the
	 * source Bean and the destination bean must either implement the same
	 * interface or be/extend the same class.  Also, this method assumes that 
	 * for each 'getXXX' or 'isXXX' method, there is a 'setXXX' method.
	 * 
	 * @param interfaceClass The interface that the source and destination implement.
	 * @param source the implementation to copy FROM.
	 * @param destination the implementation to copy TO.
	 */
	public static void copy( Class interfaceClass, Object source, Object destination ) throws SystemException {

		try {
			Method[] methods = interfaceClass.getMethods();
		
			int numMethods = methods.length;
			Method method;
			String methodName;
			Method newMethod;
			String newMethodName;
			Class[] argTypes;
			Object[] args;
		
			for( int index = 0; index < numMethods; index++ ) {
				method = methods[ index ];
				methodName = method.getName();
				
				if( methodName.startsWith( "get" ) ) {
				
					newMethodName = "set" + methodName.substring( 3 );
					argTypes = new Class[1];
					argTypes[0] = method.getReturnType();
					
					args = new Object[1];
					args[0] = method.invoke( source, null );
					
					newMethod = destination.getClass().getMethod( newMethodName, argTypes );
					
					newMethod.invoke( destination, args );
				} 
				else if( methodName.startsWith( "is" ) ) {
				
					newMethodName = "set" + methodName.substring( 2 );
					argTypes = new Class[1];
					argTypes[0] = method.getReturnType();
					
					args = new Object[1];
					args[0] = method.invoke( source, null );
					
					newMethod = destination.getClass().getMethod( newMethodName, argTypes );
					
					newMethod.invoke( destination, args );
				}
			}
		}
		catch( Exception e ) {
			throw new SystemException( "Error Copying Beans", e );
		}
	}
	
	//***************************************************************
    // Variables

    /** Logger for this class.  */
    private static Log _log = LogFactory.getLog( BeanService.class );

}
